==> eam-wshub-proxyclient-11.6-2-sources.jar: net/datastream/schemas/mp_fields/UPLOADTABLES.java <==

package net.datastream.schemas.mp_fields;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}UPLOADTABLE" maxOccurs="unbounded"/>
 *       &lt;/sequence>
 *       &lt;attribute name="includedependents" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" default="false" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "uploadtable"
})
@XmlRootElement(name = "UPLOADTABLES")
public class UPLOADTABLES {

    @XmlElement(name = "UPLOADTABLE", required = true)
    protected List<String> uploadtable;
    @XmlAttribute(name = "includedependents")
    protected String includedependents;

    /**
     * Gets the value of the uploadtable property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the uploadtable property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getUPLOADTABLE().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link String }
     * 
     * 
     */
    public List<String> getUPLOADTABLE() {
        if (uploadtable == null) {
            uploadtable = new ArrayList<String>();
        }
        return this.uploadtable;
    }

    /**
     * Obtient la valeur de la propriété includedependents.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getIncludedependents() {
        if (includedependents == null) {
            return "false";
        } else {
            return includedependents;
        }
    }

    /**
     * Définit la valeur de la propriété includedependents.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setIncludedependents(String value) {
        this.includedependents = value;
    }

}

==> eam-wshub-proxyclient-11.7-3-sources.jar: net/datastream/schemas/mp_fields/UPLOADTABLES.java <==

package net.datastream.schemas.mp_fields;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}UPLOADTABLE" maxOccurs="unbounded"/>
 *       &lt;/sequence>
 *       &lt;attribute name="includedependents" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" default="false" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "uploadtable"
})
@XmlRootElement(name = "UPLOADTABLES")
public class UPLOADTABLES {

    @XmlElement(name = "UPLOADTABLE", required = true)
    protected List<String> uploadtable;
    @XmlAttribute(name = "includedependents")
    protected String includedependents;

    /**
     * Gets the value of the uploadtable property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the uploadtable property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getUPLOADTABLE().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link String }
     * 
     * 
     */
    public List<String> getUPLOADTABLE() {
        if (uploadtable == null) {
            uploadtable = new ArrayList<String>();
        }
        return this.uploadtable;
    }

    /**
     * Gets the value of the includedependents property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getIncludedependents() {
        if (includedependents == null) {
            return "false";
        } else {
            return includedependents;
        }
    }

    /**
     * Sets the value of the includedependents property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setIncludedependents(String value) {
        this.includedependents = value;
    }

}
